---
sidebar_label: list
title: data_structures.predefined.list
---

## List Objects

```python
class List(DataStructure)
```

This class serializes python list

soil.data(my_list) will create a list automatically.

